const express = require('express');
const dotenv = require('dotenv');
const path = require('path');
const session = require('express-session');
const authRoutes = require('./routes/authRoutes');
const productRoutes = require('./routes/productRoutes');
const orderRoutes = require('./routes/orderRoutes');

// โหลดค่าตัวแปรจาก .env
dotenv.config();

const app = express();

// Middleware
app.use(express.json());
app.use(express.urlencoded({ extended: true }));
app.use(express.static(path.join(__dirname, 'public')));
app.set('view engine', 'ejs');

// ตั้งค่า session
app.use(session({
    secret: process.env.SESSION_SECRET || 'your-secret-key',
    resave: false,
    saveUninitialized: false,
    cookie: { secure: false } // ตั้งเป็น true ถ้าใช้ HTTPS
}));

// Middleware ตรวจสอบการล็อกอิน
const checkLogin = (req, res, next) => {
    if (req.session.user) {
        next();
    } else {
        res.redirect('/auth/login');
    }
};

// Routes
app.use('/auth', authRoutes);  // ใช้เส้นทางจาก authRoutes.js
app.use('/products', checkLogin, productRoutes);  // ใช้เส้นทางจาก productRoutes.js และต้องล็อกอินก่อน
app.use('/orders', checkLogin, orderRoutes);  // ใช้เส้นทางจาก orderRoutes.js และต้องล็อกอินก่อน

// หน้าแรก
app.get('/', checkLogin, (req, res) => {
    res.redirect('/products');
});

// เริ่ม server
const PORT = process.env.PORT || 3000;
app.listen(PORT, () => {
    console.log(`Server running on port ${PORT}`);
});
