const bcrypt = require('bcrypt');
const authModel = require('../models/authModel');
const db = require('../config/db');

// แสดงหน้า login
exports.loginPage = (req, res) => {
    res.render('login', { error: null });
};

// เข้าสู่ระบบ
exports.login = async (req, res) => {
    try {
        const { username, password } = req.body;
        
        // ตรวจสอบว่ามีการกรอกข้อมูลครบหรือไม่
        if (!username || !password) {
            return res.render('login', { error: 'กรุณากรอกชื่อผู้ใช้และรหัสผ่าน' });
        }

        // ค้นหาผู้ใช้จากฐานข้อมูล
        const user = await db.query('SELECT * FROM users WHERE username = ?', [username]);
        
        // ตรวจสอบว่าพบผู้ใช้หรือไม่
        if (!user || user.length === 0) {
            return res.render('login', { error: 'ชื่อผู้ใช้หรือรหัสผ่านไม่ถูกต้อง' });
        }

        // ตรวจสอบรหัสผ่าน
        const validPassword = await bcrypt.compare(password, user[0].password);
        
        if (!validPassword) {
            return res.render('login', { error: 'ชื่อผู้ใช้หรือรหัสผ่านไม่ถูกต้อง' });
        }

        // สร้าง session
        req.session.user = {
            id: user[0].id,
            username: user[0].username,
            role: user[0].role
        };

        // redirect ไปหน้า index
        res.redirect('/');
    } catch (error) {
        console.error('Login error:', error);
        res.render('login', { error: 'เกิดข้อผิดพลาดในการเข้าสู่ระบบ กรุณาลองใหม่อีกครั้ง' });
    }
};

exports.registerPage = (req, res) => {
    res.render('register', { error: null }); // แสดงหน้า Register Form
};

exports.register = async (req, res) => {
    try {
        const { username, password } = req.body;

        // ตรวจสอบว่ามีการกรอกข้อมูลครบหรือไม่
        if (!username || !password) {
            return res.render('register', { error: 'กรุณากรอกชื่อผู้ใช้และรหัสผ่าน' });
        }

        // ตรวจสอบว่ามี username นี้อยู่แล้วหรือไม่
        const existingUsers = await db.query('SELECT * FROM users WHERE username = ?', [username]);
        if (existingUsers.length > 0) {
            return res.render('register', { error: 'ชื่อผู้ใช้นี้มีอยู่ในระบบแล้ว' });
        }

        // เข้ารหัสรหัสผ่าน
        const hashedPassword = await bcrypt.hash(password, 10);

        // สร้างผู้ใช้ใหม่
        await db.query(
            'INSERT INTO users (username, password) VALUES (?, ?)',
            [username, hashedPassword]
        );

        // redirect ไปหน้า login
        res.redirect('/auth/login');
    } catch (error) {
        console.error('Register error:', error);
        res.render('register', { error: 'เกิดข้อผิดพลาดในการลงทะเบียน กรุณาลองใหม่อีกครั้ง' });
    }
};

// ออกจากระบบ
exports.logout = (req, res) => {
    req.session.destroy((err) => {
        if (err) {
            console.error('Logout error:', err);
            return res.status(500).send('Error logging out');
        }
        res.redirect('/auth/login');
    });
};
