const db = require('../config/db');

// ดึงรายการคำสั่งซื้อทั้งหมด
exports.getAllOrders = async () => {
    const query = `
        SELECT o.*, p.name as product_name, p.price as product_price 
        FROM orders o 
        JOIN products p ON o.product_id = p.id 
        ORDER BY o.order_date DESC
    `;
    
    return await db.query(query);
};

// สร้างคำสั่งซื้อใหม่
exports.createOrder = async (productId, quantity) => {
    try {
        // ตรวจสอบว่ามีสินค้าอยู่จริงหรือไม่
        const products = await db.query('SELECT * FROM products WHERE id = ?', [productId]);
        if (products.length === 0) {
            throw new Error('Product not found');
        }

        const product = products[0];
        
        // ตรวจสอบว่ามีสินค้าเพียงพอหรือไม่
        if (product.quantity < quantity) {
            throw new Error('Insufficient stock');
        }

        // อัพเดทจำนวนสินค้า
        await db.query(
            'UPDATE products SET quantity = quantity - ? WHERE id = ?',
            [quantity, productId]
        );

        // สร้าง order
        const result = await db.query(
            'INSERT INTO orders (product_id, quantity, order_date) VALUES (?, ?, NOW())',
            [productId, quantity]
        );

        return result.insertId;
    } catch (error) {
        throw error;
    }
};

// อัพเดทสถานะคำสั่งซื้อ
exports.updateOrderStatus = async (order_id, status) => {
    return await db.query('UPDATE orders SET status = ? WHERE id = ?', [status, order_id]);
}; 