const express = require('express');
const router = express.Router();
const db = require('../config/db');

// Place Order route
router.post('/place/:id', async (req, res) => {
    try {
        const productId = req.params.id;
        const orderQuantity = parseInt(req.body.quantity) || 1;

        // ตรวจสอบสินค้า
        const [product] = await db.query('SELECT * FROM products WHERE id = ?', [productId]);
        
        if (!product) {
            return res.status(404).send('Product not found');
        }

        // ตรวจสอบจำนวนสินค้าคงเหลือ
        if (product.quantity < orderQuantity) {
            return res.status(400).send('Not enough stock');
        }

        // อัพเดทจำนวนสินค้า
        await db.query(
            'UPDATE products SET quantity = quantity - ? WHERE id = ? AND quantity >= ?',
            [orderQuantity, productId, orderQuantity]
        );
        
        // Redirect to success page
        res.redirect('/orders/success');
    } catch (error) {
        console.error('Error placing order:', error);
        res.status(500).send('Error placing order');
    }
});

// Order Success page
router.get('/success', (req, res) => {
    res.render('orderSuccess');
});

module.exports = router; 